aboutsummaryrefslogtreecommitdiffstats
path: root/p2p/discover/database.go
diff options
context:
space:
mode:
authorFelix Lange <fjl@twurst.com>2018-02-17 03:16:23 +0800
committerFelix Lange <fjl@twurst.com>2018-02-17 04:29:20 +0800
commitaeedec4078647c22244552803c88521391224ab1 (patch)
tree2cead3501991bb474f0a50727b625fea75700797 /p2p/discover/database.go
parent32301a4d6b3a9684e954057e7cdb15998764122b (diff)
downloadgo-tangerine-aeedec4078647c22244552803c88521391224ab1.tar
go-tangerine-aeedec4078647c22244552803c88521391224ab1.tar.gz
go-tangerine-aeedec4078647c22244552803c88521391224ab1.tar.bz2
go-tangerine-aeedec4078647c22244552803c88521391224ab1.tar.lz
go-tangerine-aeedec4078647c22244552803c88521391224ab1.tar.xz
go-tangerine-aeedec4078647c22244552803c88521391224ab1.tar.zst
go-tangerine-aeedec4078647c22244552803c88521391224ab1.zip
p2p/discover: s/lastPong/bondTime/, update TestUDP_findnode
I forgot to change the check in udp.go when I changed Table.bond to be based on lastPong instead of node presence in db. Rename lastPong to bondTime and add hasBond so it's clearer what this DB key is used for now.
Diffstat (limited to 'p2p/discover/database.go')
-rw-r--r--p2p/discover/database.go17
1 files changed, 11 insertions, 6 deletions
diff --git a/p2p/discover/database.go b/p2p/discover/database.go
index b136609f2..6f98de9b4 100644
--- a/p2p/discover/database.go
+++ b/p2p/discover/database.go
@@ -257,7 +257,7 @@ func (db *nodeDB) expireNodes() error {
}
// Skip the node if not expired yet (and not self)
if !bytes.Equal(id[:], db.self[:]) {
- if seen := db.lastPong(id); seen.After(threshold) {
+ if seen := db.bondTime(id); seen.After(threshold) {
continue
}
}
@@ -278,13 +278,18 @@ func (db *nodeDB) updateLastPing(id NodeID, instance time.Time) error {
return db.storeInt64(makeKey(id, nodeDBDiscoverPing), instance.Unix())
}
-// lastPong retrieves the time of the last successful contact from remote node.
-func (db *nodeDB) lastPong(id NodeID) time.Time {
+// bondTime retrieves the time of the last successful pong from remote node.
+func (db *nodeDB) bondTime(id NodeID) time.Time {
return time.Unix(db.fetchInt64(makeKey(id, nodeDBDiscoverPong)), 0)
}
-// updateLastPong updates the last time a remote node successfully contacted.
-func (db *nodeDB) updateLastPong(id NodeID, instance time.Time) error {
+// hasBond reports whether the given node is considered bonded.
+func (db *nodeDB) hasBond(id NodeID) bool {
+ return time.Since(db.bondTime(id)) < nodeDBNodeExpiration
+}
+
+// updateBondTime updates the last pong time of a node.
+func (db *nodeDB) updateBondTime(id NodeID, instance time.Time) error {
return db.storeInt64(makeKey(id, nodeDBDiscoverPong), instance.Unix())
}
@@ -327,7 +332,7 @@ seek:
if n.ID == db.self {
continue seek
}
- if now.Sub(db.lastPong(n.ID)) > maxAge {
+ if now.Sub(db.bondTime(n.ID)) > maxAge {
continue seek
}
for i := range nodes {